pub enum Chunk {
Inline(Box<[u8]>),
External(ContentReference),
}Expand description
A chunk of data in a zstd:chunked stream. Either contains inline data or a reference to a compressed range (and checksum and size information about the data at that range).
Variants
Inline(Box<[u8]>)
The literal data appears directly.
External(ContentReference)
The data appears at the referenced range, which may need to be fetched and decompressed.