pub struct ContentReference {
pub range: Range<u64>,
pub digest: String,
pub size: u64,
}Expand description
A reference to a compressed range in a zstd:chunked file, along with size and checksum information about the uncompressed data at that range.
Fields
range: Range<u64>The range itself, in bytes, in the compressed file.
digest: StringThe digest of the data at the range, after decompression.
size: u64The size of the compressed data at the range, after decompression.