pub struct MetadataReference {
pub range: Range<u64>,
pub digest: Option<String>,
pub uncompressed_size: u64,
}Expand description
A reference to file metadata, either the manifest or the tarsplit
Fields
range: Range<u64>The range itself, in bytes, in the compressed file.
digest: Option<String>The digest of the data at the range, before decompression. This will be missing if we read from the file footer or if the OCI annotations didn’t provide it.
uncompressed_size: u64The size of the compressed data at the range, after decompression.