pub struct MetadataReferences {
pub manifest: MetadataReference,
pub tarsplit: MetadataReference,
}Expand description
References to the manifest and tarsplit metadata. You can read these from the file footer or from the annotations on the OCI layer descriptor.
Fields
manifest: MetadataReferenceThe location of the manifest data
tarsplit: MetadataReferenceThe location of the tarsplit data
Implementations
Sourceimpl MetadataReferences
impl MetadataReferences
Read the metadata references from the file footer. The provided data can be any suffix of the file, but it must be at least 72 bytes in length (to contain the footer). Returns None if this doesn’t appear to be a zstd:chunked file.
Sourcepub fn from_oci(annotations: HashMap<String, String>) -> Option<Self>
pub fn from_oci(annotations: HashMap<String, String>) -> Option<Self>
Parses the metadata references from OCI layer descriptor annotations. The type of the
annotations HashMap was chosen to be compatible with the oci-spec crate. Returns None if
this doesn’t appear to be a zstd:chunked layer descriptor.